package com.yeejoin.amos.fas.business.controller;

import com.yeejoin.amos.fas.business.param.PointListParam;
import com.yeejoin.amos.fas.business.param.QueryParamUtil;
import com.yeejoin.amos.fas.business.service.intfc.ICommonService;
import com.yeejoin.amos.fas.core.common.request.CommonPageable;
import com.yeejoin.amos.fas.core.common.request.CommonRequest;
import com.yeejoin.amos.fas.dao.entity.SDepartment;
import com.yeejoin.amos.fas.dao.entity.SUser;
import com.yeejoin.amos.op.core.common.response.CommonResponse;
import com.yeejoin.amos.op.core.util.CommonResponseUtil;
import com.yeejoin.amos.security.authorization.Authorization;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;

@RestController
@RequestMapping(value = "/api/common")
@Api(tags = "公共资源api")
public class CommonController extends BaseController {

    @Autowired
    private ICommonService commonService;

    private final Logger log = LoggerFactory.getLogger(CommonController.class);


    /**
     * 根据当前用户获取公司下部门信息
     *
     * @return
     */
    @ApiOperation(httpMethod = "GET", value = "根据当前用户获取公司下部门信息", notes = "根据当前用户获取公司下部门信息")
    @RequestMapping(value = "/deptment/list", produces = "application/json;charset=UTF-8", method = RequestMethod.GET)
    public CommonResponse getDeptments() {
        Long companyId = getCompanyId();
        if (companyId == null) {
            return CommonResponseUtil.failure("公司信息获取失败！");
        }
        List<SDepartment> deps = commonService.getDepartment(companyId);
        return CommonResponseUtil.success(deps);
    }

    /**
     * 查询巡检点信息
     *
     * @param
     * @return
     */
    @ApiOperation(value = "查询巡检点信息", notes = "查询巡检点信息")
    @PostMapping(value = "/pointList", produces = "application/json;charset=UTF-8")
    public CommonResponse getPoints(
            @ApiParam(value = "查询条件", required = false) @RequestBody(required = false) List<CommonRequest> queryRequests,
            @ApiParam(value = "分页参数", required = true, defaultValue = "pageNumber=0&pageSize=10") CommonPageable commonPageable) {

        try {
            PointListParam params = new PointListParam();
            QueryParamUtil.fillPointListParam(queryRequests, commonPageable, params);
            Page<HashMap<String, Object>> pointList = commonService.getPointList(params);
            return CommonResponseUtil.success(pointList);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            return CommonResponseUtil.failure("查询巡检点信息失败");
        }
    }


    /**
     * 根据巡检点查询巡检项
     *
     * @param
     * @return
     */
    @Authorization(ingore = true)
    @ApiOperation(value = "查询巡检点项信息", notes = "查询巡检点项信息")
    @PostMapping(value = "/pointInputlist", produces = "application/json;charset=UTF-8")
    public CommonResponse getPointInputs(
            @ApiParam(value = "查询条件", required = false) @RequestBody(required = false) List<CommonRequest> queryRequests,
            @ApiParam(value = "分页参数", required = true, defaultValue = "pageNumber=0&pageSize=10") CommonPageable commonPageable) {

        try {
            PointListParam params = new PointListParam();
//			params.setOrgCode(getUserInfo().getOrgCode());
            QueryParamUtil.fillPointListParam(queryRequests, commonPageable, params);
            Page<HashMap<String, Object>> pointInputList = commonService.getPointInputList(params);
            return CommonResponseUtil.success(pointInputList);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            return CommonResponseUtil.failure("查询巡检点信息失败");
        }
    }

    /**
     * 根据部门获取部门人员信息
     *
     * @return
     */
    @ApiOperation(httpMethod = "GET", value = "根据部门获取部门人员信息", notes = "根据部门获取部门人员信息")
    @RequestMapping(value = "/{departmentId}/user/list", produces = "application/json;charset=UTF-8", method = RequestMethod.GET)
    public CommonResponse getUsers(@ApiParam(value = "部门ID", required = true) @PathVariable Long departmentId) {
        if (departmentId == null) {
            return CommonResponseUtil.failure("部门信息获取失败！");
        }
        List<SUser> users = commonService.getUsers(departmentId);
        return CommonResponseUtil.success(users);
    }
}
