package com.yeejoin.amos.fas.business.controller;

import com.yeejoin.amos.fas.business.param.CommonPageInfoParam;
import com.yeejoin.amos.fas.business.param.RiskFmeaParam;
import com.yeejoin.amos.fas.business.service.intfc.IFmeaService;
import com.yeejoin.amos.fas.business.service.intfc.IRiskSourceService;
import com.yeejoin.amos.fas.business.util.CommonPageParamUtil;
import com.yeejoin.amos.fas.client.invoke.RsDataQueue;
import com.yeejoin.amos.fas.core.common.request.CommonPageable;
import com.yeejoin.amos.fas.core.common.request.CommonRequest;
import com.yeejoin.amos.fas.dao.entity.Fmea;
import com.yeejoin.amos.fas.dao.entity.RiskSource;
import com.yeejoin.amos.op.core.common.response.CommonResponse;
import com.yeejoin.amos.op.core.util.CommonResponseUtil;
import com.yeejoin.amos.security.authorization.Authorization;
import com.yeejoin.amos.security.entity.User;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.repository.query.Param;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;

@RestController
@RequestMapping("/api/riskModel")
@Api(tags="风险模型api")
public class RiskModelController extends BaseController {

	private final Logger log = LoggerFactory.getLogger(RiskLevelController.class);
	
	@Autowired
	private IRiskSourceService riskSourceService;
	
	@Autowired
	private IFmeaService fmeaService;




	/**
	 * 风险模型新增及维护
	 * @param param
	 * @return
	 */
	@ApiOperation(httpMethod = "POST", value = "风险模型新增及维护", notes = "风险模型新增及维护")
	@RequestMapping(value = "/riskSource/editRiskSource", produces = "application/json;charset=UTF-8", method = RequestMethod.POST)
	public CommonResponse editRiskSource(@ApiParam(value = "风险模型对象", required = true) @RequestBody RiskSource param) {
		try {
			User user = getUserInfo();
			HashMap<String,Object> map = new HashMap<String,Object>();
			map.put("org_code", user.getOrgCode());
			map.put("user_id", user.getId());
			map.put("param", param);
			riskSourceService.editRiskSource(map);
			return CommonResponseUtil.success();
		} catch (Exception e) {
			log.error(e.getMessage(),e);
			return CommonResponseUtil.failure("风险模型新增及维护失败："+e.getMessage());
		}
	}
	
	/**
	 * 风险模型删除
	 * @param param
	 * @return
	 */
	@ApiOperation(httpMethod = "POST", value = "风险模型删除", notes = "风险模型删除")
	@Authorization(ingore = true)
	@RequestMapping(value = "/riskSource/deleteRiskSource", produces = "application/json;charset=UTF-8", method = RequestMethod.POST)
	public CommonResponse deleteRiskSource(@ApiParam(value = "风险模型id", required = true) @RequestBody Long[] riskSourceId) {
		try {
			riskSourceService.deleteRiskSource(riskSourceId);
			return CommonResponseUtil.success();
		} catch (Exception e) {
			log.error(e.getMessage(),e);
			return CommonResponseUtil.failure("风险模型删除失败："+e.getMessage());
		}
	}
	
	/**
	 * 风险点列表分页查询
	 * 
	 * @param id
	 * @return
	 */
	@ApiOperation(httpMethod = "POST",value = "风险点列表分页查询", notes = "风险点列表分页查询")
	@RequestMapping(value = "/riskSource/list", produces = "application/json;charset=UTF-8", method = RequestMethod.POST)
	public CommonResponse queryRiskSourceByPage(
			@ApiParam(value = "查询条件", required = false) @RequestBody(required = false) List<CommonRequest> queryRequests,
			@ApiParam(value = "分页参数", required = true) CommonPageable commonPageable) {
		CommonPageInfoParam param = CommonPageParamUtil.fillCommonPageInfoParam(queryRequests, commonPageable);
		Page<HashMap<String, Object>> riskSourceList = riskSourceService.queryRiskSourceByPage(param);
		return CommonResponseUtil.success(riskSourceList);	  
	}

	/**
	 * Fmea模型新增及维护
	 * @param param
	 * @return
	 */
	@ApiOperation(httpMethod = "POST", value = "Fmea模型新增及维护", notes = "Fmea模型新增及维护")
	@RequestMapping(value = "/fmea/editFmea", produces = "application/json;charset=UTF-8", method = RequestMethod.POST)
	public CommonResponse editFmea(@ApiParam(value = "Fmea模型对象", required = true) @RequestBody Fmea param) {
		try {
			User user = getUserInfo();
			HashMap<String,Object> map = new HashMap<String,Object>();
			map.put("user_id", user.getId());
			map.put("fmea", param);
			fmeaService.editFmea(map);
			RsDataQueue rs = RsDataQueue.getInstance();
			if (!ObjectUtils.isEmpty(param.getRiskSourceId())) {
				rs.add(param.getRiskSourceId());
			}
				
			return CommonResponseUtil.success();
		} catch (Exception e) {
			log.error(e.getMessage(),e);
			return CommonResponseUtil.failure("Fmea模型新增及维护失败："+e.getMessage());
		}
	}
	
	/**
	 * Fmea模型删除
	 * @param param
	 * @return
	 */
	@ApiOperation(httpMethod = "POST", value = "Fmea模型删除", notes = "Fmea模型删除")
	@RequestMapping(value = "/fmea/deleteFmea", produces = "application/json;charset=UTF-8", method = RequestMethod.POST)
	public CommonResponse deleteFmea(@ApiParam(value = "Fmea模型id", required = true) @RequestBody RiskFmeaParam param) {
		try {
			Long[]  fmeaIds = param.getFmeaIds();
			Long riskSourceId = param.getRiskSourceId();
			fmeaService.deleteFmea(fmeaIds);

			fmeaService.updateRpniInfo(riskSourceId);
			RsDataQueue rs = RsDataQueue.getInstance();
			if (!ObjectUtils.isEmpty(riskSourceId)) {
				rs.add(riskSourceId);
			}
			return CommonResponseUtil.success();
		} catch (Exception e) {
			log.error(e.getMessage(),e);
			return CommonResponseUtil.failure("Fmea模型删除失败："+e.getMessage());
		}
	}
	
	/**
	 * Fmea列表分页查询
	 * 
	 * @param id
	 * @return
	 */
	@ApiOperation(httpMethod = "POST",value = "Fmea列表分页查询", notes = "Fmea列表分页查询")
	@RequestMapping(value = "/fmea/list", produces = "application/json;charset=UTF-8", method = RequestMethod.POST)
	public CommonResponse queryFmeaByPage(@ApiParam(value = "查询条件", required = false) @RequestBody(required = false) List<CommonRequest> queryRequests,
			@ApiParam(value = "分页参数", required = true) CommonPageable commonPageable) {
		CommonPageInfoParam param = CommonPageParamUtil.fillCommonPageInfoParam(queryRequests, commonPageable);
		Page<HashMap<String, Object>> fmeaList = fmeaService.queryFmeaList(param);
		return CommonResponseUtil.success(fmeaList);	  
	}
}
