package com.yeejoin.amos.fas.business.service.impl;


import com.yeejoin.amos.fas.business.constants.FasConstant;
import com.yeejoin.amos.fas.business.dao.mapper.FireEquipMapper;
import com.yeejoin.amos.fas.business.dao.mapper.ImpAndFireEquipMapper;
import com.yeejoin.amos.fas.business.dao.mapper.ImpEquipMapper;
import com.yeejoin.amos.fas.business.dao.mapper.Node3dVoMapper;
import com.yeejoin.amos.fas.business.dao.mongo.EquipCommunicationDao;
import com.yeejoin.amos.fas.business.dao.repository.IEquipmentDao;
import com.yeejoin.amos.fas.business.dao.repository.IEquipmentFireEquipmentDao;
import com.yeejoin.amos.fas.business.dao.repository.IFireEquipmentDao;
import com.yeejoin.amos.fas.business.dao.repository.IPreplanPictureDao;
import com.yeejoin.amos.fas.business.entity.mybatis.FireEquipmentEntity;
import com.yeejoin.amos.fas.business.param.ImgParam;
import com.yeejoin.amos.fas.business.service.intfc.IEquipmentService;
import com.yeejoin.amos.fas.business.vo.EquipCommunicationData;
import com.yeejoin.amos.fas.core.common.request.CommonPageable;
import com.yeejoin.amos.fas.core.common.response.EquipDetailsResponse;
import com.yeejoin.amos.fas.core.util.query.BaseQuerySpecification;
import com.yeejoin.amos.fas.dao.entity.Equipment;
import com.yeejoin.amos.fas.dao.entity.EquipmentFireEquipment;
import com.yeejoin.amos.fas.dao.entity.FireEquipment;
import com.yeejoin.amos.fas.dao.entity.PreplanPicture;
import com.yeejoin.amos.fas.exception.YeeException;
import com.yeejoin.amos.op.core.common.query.DaoCriteria;
import com.yeejoin.amos.op.core.common.response.CommonResponse;
import com.yeejoin.amos.op.core.util.CommonResponseUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Sort;
import org.springframework.data.domain.Sort.Direction;
import org.springframework.data.domain.Sort.Order;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.data.mongodb.core.query.Criteria;
import org.springframework.data.mongodb.core.query.Query;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.util.ObjectUtils;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.PostConstruct;
import java.io.File;
import java.io.IOException;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service("equipService")
public class EquipmentServiceImpl implements IEquipmentService {

    private final Logger log = LoggerFactory.getLogger(EquipmentServiceImpl.class);

    @Autowired
    ImpEquipMapper impEquipMapper;

    @Autowired
    FireEquipMapper fireEquipMapper;

    @Autowired
    IEquipmentDao iEquipmentDao;
    @Autowired
    IPreplanPictureDao iPreplanPictureDao;

    @Autowired
    IEquipmentFireEquipmentDao equipmentFireEquipmentDao;

    @Autowired
    IFireEquipmentDao iFireEquipmentDao;

    @Autowired
    ImpAndFireEquipMapper impAndFireEquipMapper;

    @Autowired
    Node3dVoMapper node3dVoMapper;

    @Autowired
    private IPreplanPictureDao preplanPictureDao;

    @Autowired
    private RedisTemplate redisTemplate;

    @Autowired
    private MongoTemplate mongoTemplate;


    @Autowired
    private EquipCommunicationDao equipCommunicationDao;

    @Value("${windows.img.path}")
    private String winImgPath;

    @Value("${linux.img.path}")
    private String linuxImgPath;

    public Equipment save(Equipment equipment) {
        Long eqId = equipment.getId();
        equipment = iEquipmentDao.saveAndFlush(equipment);
        if (eqId == null || eqId == 0) {
            node3dVoMapper.incrementalCreateImpEqumt(equipment.getId());
        } else {
            node3dVoMapper.incrementalUpdateImpEqumt(eqId);
        }
        return equipment;
    }


    public Equipment queryOne(Long id) {
        return iEquipmentDao.findById(id);
    }

    public String[] delete(String[] idArray) throws Exception {
        for (String id : idArray) {
            Equipment equipment = iEquipmentDao.findById(Long.parseLong(id));
            if (equipment != null) {
                this.iEquipmentDao.delete(Long.parseLong(id));
                node3dVoMapper.incrementalDeleteImpEqumt(Long.parseLong(id));
            } else {
                throw new Exception("找不到指定的对象:" + id);
            }
        }

        return idArray;
    }


    @Override
    public List<PreplanPicture> queryImgByIdAndType(List<DaoCriteria> criterias) {
        BaseQuerySpecification<PreplanPicture> spec = new BaseQuerySpecification<>(criterias);
        return iPreplanPictureDao.findAll(spec);
    }

    @Override
    public Page<Equipment> queryImpEquip(List<DaoCriteria> criterias, CommonPageable commonPageable) {
        String name = "";
        for (DaoCriteria criteria : criterias) {
            if (criteria.getPropertyName().equals("name")) {
                name = String.valueOf(criteria.getValue() != null ? criteria.getValue().toString() : "");
            }
        }
        Long total = impEquipMapper.getEquipPageCount(name);
        List<Map> content = impEquipMapper.getEquipPage(name, commonPageable.getOffset(),
                commonPageable.getPageSize());
        Page result = new PageImpl(content, commonPageable, total);
        return result;
    }

    @Override
    public List<Equipment> queryEquipNoPage() {
        return iEquipmentDao.findAll();
    }


    /**
     * 绑定消防设备
     *
     * @param list
     * @return
     * @throws Exception
     */
    @Transactional(rollbackFor = Exception.class)
    public List<Map<String, Object>> bindFireEqumt(BigInteger equipmentId, List<EquipmentFireEquipment> list) throws Exception {
        List<Map<String, Object>> resultList = new ArrayList<>();
        for (EquipmentFireEquipment equipmentFireEquipment : list) {
            int count = equipmentFireEquipmentDao.findByEqmtIdAndFireEqmtId(equipmentId, equipmentFireEquipment.getFireEquipmentId());
            if (count > 0) {
                continue;
            }
            equipmentFireEquipment.setEquipmentId(equipmentId);
            equipmentFireEquipment.setCreateDate(new Date());
            Map<String, Object> result = new HashMap<>();
            result.put("exits", false);
            Equipment equipment = this.iEquipmentDao.getOne(equipmentFireEquipment.getEquipmentId().longValue());
            FireEquipment fireEquipment = iFireEquipmentDao.getOne(equipmentFireEquipment.getFireEquipmentId().longValue());

            if (equipment == null || fireEquipment == null)
                throw new Exception("找不到数据");

            this.equipmentFireEquipmentDao.save(equipmentFireEquipment);

            //已存在的绑定关系
            List<EquipmentFireEquipment> exits = impAndFireEquipMapper.queryForList(String.valueOf(equipmentFireEquipment.getFireEquipmentId()), null);

            if (!CollectionUtils.isEmpty(exits))
                result.put("exits", true);
            result.put("newModel", equipmentFireEquipment);

            resultList.add(result);
        }

        return resultList;
    }


    @Transactional(rollbackFor = Exception.class)
    public List<Long> removeFireEqmtBind(BigInteger equipmentId, String[] fireEquipmentIds) {
        List<Long> ids = new ArrayList<>();
        for (String id : fireEquipmentIds) {
            long result = 0;
            EquipmentFireEquipment equipmentFireEquipment = impAndFireEquipMapper.queryForOne(String.valueOf(id), String.valueOf(equipmentId));

            if (equipmentFireEquipment != null) {
                result = equipmentFireEquipment.getId();
                this.equipmentFireEquipmentDao.delete(equipmentFireEquipment.getId());
            }
            ids.add(result);
        }

        return ids;
    }


    /**
     * 查询指定重点设备已经绑定的消防设备
     *
     * @param equipmentId
     * @return
     */
    public Page queryBindFirEqumtList(CommonPageable commonPageable, BigInteger equipmentId) {
        int start = -1;
        int length = -1;
        if (null != commonPageable) {
            start = commonPageable.getOffset();
            length = commonPageable.getPageSize();
        }
        long total = this.impAndFireEquipMapper.queryBindFirEqumtPageCount(String.valueOf(equipmentId));
        List<FireEquipment> list = this.impAndFireEquipMapper.queryBindFirEqumtPage(start, length, String.valueOf(equipmentId));
        Page result = new PageImpl(list, commonPageable, total);
        return result;
    }


    @Override
    public Equipment saveImg(MultipartFile file, Equipment equipment, int type, Long userId) {
        // TODO Auto-generated method stub
        BigInteger equipmentId = BigInteger.valueOf(equipment.getId());

        PreplanPicture pp = preplanPictureDao.selectOne(equipmentId, type);
        if (pp == null) {
            pp = new PreplanPicture();
            pp.setEquipmentId(equipmentId);
            pp.setType(type);
            pp.setCreateDate(new Date());
            pp.setCreateBy(userId.intValue());
        }

        String path = FasConstant.UPLOAD_ROOT_PATH + File.separator + FasConstant.UPLOAD_EQUIPMENT_PATH + File.separator
                + equipment.getId();
        String filePath = getRootPath() + path;

        String fileType = file.getOriginalFilename().substring(file.getOriginalFilename().lastIndexOf("."),
                file.getOriginalFilename().length());
        String fileName = File.separator + type + fileType;

        try {
            File dest = new File(filePath + File.separator + fileName);
            if (!dest.exists()) {
                if (dest.getParentFile() != null && !dest.getParentFile().exists()) {
                    dest.getParentFile().mkdirs();
                }
                dest.createNewFile();
            }
            file.transferTo(dest);
        } catch (IOException e) {
            throw new YeeException("上传图片失败");
        }
        String picture = path + fileName;
        pp.setCreateBy(userId.intValue());
        pp.setPicture(picture);
        if (equipment.getCreateDate() == null) {
            equipment.setCreateDate(iEquipmentDao.findById(equipment.getId()).getCreateDate());
        }

        preplanPictureDao.saveAndFlush(pp);
        equipment = iEquipmentDao.saveAndFlush(equipment);
        return equipment;
    }

    private String getRootPath() {
        String localPath = "";
        if ("\\".equals(File.separator)) {
            localPath += winImgPath;
        } else if ("/".equals(File.separator)) {
            localPath += linuxImgPath;
        }
        return localPath.trim();
    }


    @Override
    public Equipment saveEquipmentAndImg(ImgParam[] imgs, Equipment equipment) {
        // TODO Auto-generated method stub
        if (imgs == null || imgs.length < 1) {
            equipment = save(equipment);
            if (equipment.getCreateDate() == null) {
                equipment.setCreateDate(iEquipmentDao.findById(equipment.getId()).getCreateDate() == null ? new Date() : iEquipmentDao.findById(equipment.getId()).getCreateDate());
            }
        } else {
            equipment = save(equipment);
            if (equipment.getCreateDate() == null) {
                equipment.setCreateDate(iEquipmentDao.findById(equipment.getId()).getCreateDate() == null ? new Date() : iEquipmentDao.findById(equipment.getId()).getCreateDate());
            }
            BigInteger equipmentId = BigInteger.valueOf(equipment.getId());
            for (int i = 0; i < imgs.length; i++) {
                MultipartFile file = imgs[i].getFile();
                if (null != file) {
                    int type = imgs[i].getType();
                    PreplanPicture pp = preplanPictureDao.selectOne(equipmentId, type);
                    if (pp == null) {
                        pp = new PreplanPicture();
                        pp.setEquipmentId(equipmentId);
                        pp.setType(type);
                        pp.setCreateDate(new Date());
                    }

                    String path = FasConstant.UPLOAD_ROOT_PATH + File.separator + FasConstant.UPLOAD_EQUIPMENT_PATH
                            + File.separator + equipment.getId();
                    String filePath = getRootPath() + path;

                    String fileType = file.getOriginalFilename().substring(file.getOriginalFilename().lastIndexOf("."),
                            file.getOriginalFilename().length());
                    String fileName = File.separator + type + fileType;

                    try {
                        File dest = new File(filePath + File.separator + fileName);
                        if (!dest.exists()) {
                            if (dest.getParentFile() != null && !dest.getParentFile().exists()) {
                                dest.getParentFile().mkdirs();
                            }
                            dest.createNewFile();
                        }
                        file.transferTo(dest);
                    } catch (IOException e) {
                        log.error(e.getMessage(), e);
                        throw new YeeException("上传图片失败");
                    }
                    String picture = path + fileName;
                    pp.setPicture(picture);
                    preplanPictureDao.saveAndFlush(pp);
                }
            }
            equipment = iEquipmentDao.saveAndFlush(equipment);
        }
        return equipment;
    }
	/*@Override
	public Equipment saveEquipmentAndImg(ImgParam imgs, Equipment equipment) {
		// TODO Auto-generated method stub
		if(imgs==null ){
			equipment = save(equipment);
			if(equipment.getCreateDate()==null){
				equipment.setCreateDate(iEquipmentDao.findOne(equipment.getId()).getCreateDate()==null?new Date():iEquipmentDao.findOne(equipment.getId()).getCreateDate());
			}
		}else{
			
				MultipartFile file = imgs.getFile();
				int type = imgs.getType();
				String remark = imgs.getRemark();
				equipment = save(equipment);
				if(equipment.getCreateDate()==null){
					equipment.setCreateDate(iEquipmentDao.findOne(equipment.getId()).getCreateDate()==null?new Date():iEquipmentDao.findOne(equipment.getId()).getCreateDate());
				}
				
				BigInteger equipmentId = BigInteger.valueOf(equipment.getId()); 
				
				PreplanPicture pp = preplanPictureDao.selectOne(equipmentId, type);
				if(pp == null){
					pp = new PreplanPicture();
					pp.setEquipmentId(equipmentId);
					pp.setType(type);
					pp.setRemark(remark);
					pp.setCreateDate(new Date());
				}
				
					String path = FasConstant.UPLOAD_ROOT_PATH + File.separator + FasConstant.UPLOAD_EQUIPMENT_PATH + File.separator
							+ equipment.getId();
					String filePath = getRootPath() + path;
					
					String fileType = file.getOriginalFilename().substring(file.getOriginalFilename().lastIndexOf("."),
							file.getOriginalFilename().length());
					String fileName = File.separator + type+fileType;

					try {
						File dest = new File(filePath + File.separator + fileName);
						if (!dest.exists()) {
							if (dest.getParentFile() != null && !dest.getParentFile().exists()) {
								dest.getParentFile().mkdirs();
							}
							dest.createNewFile();
						}
						file.transferTo(dest);
					} catch (IOException e) {
						throw new YeeException("上传图片失败");
					}
					String picture = path + fileName;
					pp.setPicture(picture);
					pp.setRemark(remark);
					preplanPictureDao.saveAndFlush(pp);
					equipment = iEquipmentDao.saveAndFlush(equipment);
			}
			
		
		
		
		return equipment;
	}*/


    @Override
    public List<Map<String, Object>> findEquipVideoList() {
        List<Map<String, Object>> list = impAndFireEquipMapper.findEquipVideo();
        Map<String, Map<String, Object>> tempEquip = new HashMap<String, Map<String, Object>>();
        List<Map<String, Object>> result = new ArrayList<Map<String, Object>>();
        for (Map<String, Object> temp : list) {
            Map<String, Object> equip = new HashMap<String, Object>();
            Map<String, Object> video = new HashMap<String, Object>();
            video.put("id", temp.get("id"));
            video.put("code", temp.get("code"));
            video.put("name", temp.get("name"));
            video.put("videoUrl", temp.get("url"));
            video.put("equipName", temp.get("equipName"));
            video.put("monitorTime", new Date());
            List<Map<String, Object>> videoList = new ArrayList<Map<String, Object>>();
            if (tempEquip.containsKey(temp.get("equipId").toString())) {
                equip = tempEquip.get(temp.get("equipId").toString());
                videoList = (List<Map<String, Object>>) equip.get("children");
                videoList.add(video);
            } else {
                equip.put("equipId", temp.get("equipId"));
                equip.put("equipName", temp.get("equipName"));
                equip.put("equipCode", temp.get("equipCode"));
                videoList.add(video);
                equip.put("children", videoList);
                tempEquip.put(temp.get("equipId").toString(), equip);
                result.add(equip);
            }
        }
        return result;
    }

    @Override
    public EquipDetailsResponse findEquipDetailsById(Long id) {
        return fireEquipMapper.findEquipDetailsById(id);
    }


    @Override
    public List<Equipment> findAll() {
        return iEquipmentDao.findAll();
    }


    @Override
    @PostConstruct
    public void findAllEquipPointInfo() {
        List<EquipCommunicationData> list = fireEquipMapper.findAllEquipPointInfo();
        if (!ObjectUtils.isEmpty(list)) {
            HashMap<String, EquipCommunicationData> map = new HashMap<>();
            list.forEach(data -> {
                map.put(data.getPointCode(), data);
            });
            redisTemplate.opsForHash().putAll("fireEquipData", map);
        }
    }


    @Override
    public EquipCommunicationData findFireEquipmentByPointCode(String code) {
        EquipCommunicationData data = (EquipCommunicationData) redisTemplate.opsForHash().get("fireEquipData", code);
        if (ObjectUtils.isEmpty(data)) {
            data = fireEquipMapper.findOneByPointCode(code);
        }
        return data;
    }

    @Override
    public EquipCommunicationData findFireEquipDataByPointCode(String code) {
        Query query = new Query();
        query.addCriteria(Criteria.where("pointCode").is(code)).limit(1);
        query.with(new Sort(new Order(Direction.DESC, "recDate")));
        query.limit(1);
        List<EquipCommunicationData> data = mongoTemplate.find(query, EquipCommunicationData.class);
        if (data.isEmpty()) {
            return null;
        }
        return data.get(0);
    }

}
