package com.yeejoin.amos.fas.business.service.impl;

import java.io.File;
import java.io.IOException;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import com.yeejoin.amos.fas.business.constants.FasConstant;
import com.yeejoin.amos.fas.business.dao.mapper.FireCarMapper;
import com.yeejoin.amos.fas.business.dao.mapper.Node3dVoMapper;
import com.yeejoin.amos.fas.business.dao.repository.IFireCarDao;
import com.yeejoin.amos.fas.business.param.CommonPageInfoParam;
import com.yeejoin.amos.fas.business.service.intfc.IFireCarService;
import com.yeejoin.amos.fas.business.vo.FireCarDetailVo;
import com.yeejoin.amos.fas.dao.entity.FireCar;
import com.yeejoin.amos.fas.exception.YeeException;

@Service("fireCarService")
public class FireCarServiceImpl implements IFireCarService {

	@Autowired 
	FireCarMapper fireCarMapper;
	@Autowired 
	IFireCarDao iFireCarDao;
	
	@Value("${windows.img.path}")
	private String winImgPath;

	@Value("${linux.img.path}")
	private String linuxImgPath;

	@Autowired
	Node3dVoMapper node3dVoMapper;


	public FireCar save(FireCar fireCar)
	{
		Long carId = fireCar.getId();
		fireCar = iFireCarDao.saveAndFlush(fireCar);
		if(carId ==null || carId == 0){
			node3dVoMapper.incrementalCreateFireCar(fireCar.getId());
		}else{
			node3dVoMapper.incrementalUpdateFireCar(carId);
		}
		return fireCar;
	}


	public FireCar queryOne(Long id)
	{
		return iFireCarDao.findById(id);
	}

	public String [] delete(String []idArray) throws Exception
	{
		for(String id:idArray)
		{
			FireCar fireCar = iFireCarDao.findById(Long.parseLong(id));
			if(fireCar != null)
			{
				this.iFireCarDao.delete(Long.parseLong(id));
				node3dVoMapper.incrementalDeleteFireCar(Long.parseLong(id));
			}else
			{
				throw new Exception("找不到指定的对象:"+id);
			}
		}

		return idArray;
	}



	@Override
	public Page<HashMap<String, Object>> queryFireCar(CommonPageInfoParam param) {
		long total = fireCarMapper.countPageData(param);
		List<HashMap<String, Object>> content = fireCarMapper.getFireCarPage(param);	
		Page<HashMap<String, Object>> result = new PageImpl<HashMap<String, Object>>(content, param, total);
		return result;
	}
	
	@Override
	public FireCarDetailVo findFireCarById(Long truckId) {
		FireCarDetailVo carVo = fireCarMapper.getFireCarDetailById(truckId);
		return carVo;
	}


	@Override
	@Transactional(rollbackFor = Exception.class)
	public FireCar saveFireCarAndPhoto(FireCar fireCar, MultipartFile[] files) {
		Long carId = fireCar.getId();
		fireCar.setCreateDate(new Date());
		fireCar = iFireCarDao.saveAndFlush(fireCar);
		String photoPath = "";
		for (int i = 0; i < files.length; i++) {
			MultipartFile file = files[i];
			if (file.isEmpty()) {
				continue;
			}
			String path = FasConstant.UPLOAD_ROOT_PATH + File.separator + FasConstant.UPLOAD_CAR_PATH + File.separator + fireCar.getId();
			String filePath = getRootPath() + path;
			String fileName = File.separator + file.getOriginalFilename();
			try {
				File dest = new File(filePath + File.separator + fileName);
				if (!dest.exists()) {
					if (dest.getParentFile() != null && !dest.getParentFile().exists()) {
						dest.getParentFile().mkdirs();
					}
					dest.createNewFile();
				}
				file.transferTo(dest);
			} catch (IOException e) {
				throw new YeeException("上传图片失败");
			}
			String photoFile = path + fileName;
			if (photoPath != null && photoPath != "") {
				photoPath += "," + photoFile;
			} else {
				photoPath = photoFile;
			}

		}
		
		fireCar.setPhotoPath(photoPath);
		fireCar = iFireCarDao.saveAndFlush(fireCar);
		if(carId ==null || carId == 0){
			node3dVoMapper.incrementalCreateFireCar(fireCar.getId());
		}else{
			node3dVoMapper.incrementalUpdateFireCar(carId);
		}
		return fireCar;
	}
	
	private String getRootPath() {
		String localPath = "";
		if ("\\".equals(File.separator)) {
			localPath += winImgPath;
		} else if ("/".equals(File.separator)) {
			localPath += linuxImgPath;
		}
		return localPath.trim();
	}

}
