package com.yeejoin.amos.fas.business.service.impl;

import com.google.common.collect.Lists;
import com.yeejoin.amos.fas.business.dao.repository.ITextPlanDao;
import com.yeejoin.amos.fas.business.feign.IMaasVisualServer;
import com.yeejoin.amos.fas.business.service.intfc.IMaasVisualService;
import com.yeejoin.amos.fas.business.vo.TreeSubjectVo;
import com.yeejoin.amos.fas.dao.entity.TextPlan;
import com.yeejoin.amos.op.core.common.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

@Service("maasVisualService")
public class MaasVisualServiceImpl implements IMaasVisualService {

    @Autowired
    IMaasVisualServer maasVisualServer;

    @Autowired
    ITextPlanDao iTextPlanDao;

    @Override
    public List<TreeSubjectVo> getPlanTree() {

        CommonResponse response = maasVisualServer.getTree();
        List<TreeSubjectVo> treeSubjectVos = Lists.newArrayList();
        if (null != response.getDataList()) {
            List<Object> res = (List<Object>)response.getDataList();
            if (!CollectionUtils.isEmpty(res)) {
                treeSubjectVos = listToTree(res);
            }
        }
        return treeSubjectVos;
    }

    @Override
    public void uploadTextPlan(String appId, Map<String, String> pathNameMap) {
        if (null != pathNameMap && !pathNameMap.isEmpty()) {
            for (Map.Entry<String, String> entry : pathNameMap.entrySet()) {
                TextPlan textPlan = new TextPlan();
                textPlan.setAppId(appId);
                textPlan.setTextName(entry.getValue());
                textPlan.setFilePath(entry.getKey());
                iTextPlanDao.save(textPlan);
            }
        }
    }

    @Override
    public TextPlan getTextPlanInfoById(Long id) {
        return iTextPlanDao.findOne(id);
    }

    private List<TreeSubjectVo> listToTree(List<Object> list) {
        List<TreeSubjectVo> treeSubjectVos = Lists.newArrayList();
        for (Object obj : list) {
            TreeSubjectVo treeItem = new TreeSubjectVo();
            LinkedHashMap<String, Object> map = (LinkedHashMap<String, Object>) obj;
            treeItem.setId((Integer) map.get("id"));
            treeItem.setTreeName((String) map.get("treeName"));
            treeItem.setParentId((Integer) map.get("parentId"));
            treeItem.setMaxSubjectNumber((Integer) map.get("maxSubjectNumber"));
            treeItem.setType("treeNode");

            List<Object> children = (List<Object>) map.get("children");
            if (null != children) {
                List<TreeSubjectVo> subjectVos = listToTree(children);
                treeItem.setChildren(subjectVos);
            }

            CommonResponse response = maasVisualServer.getSubjectById(String.valueOf(map.get("id")));
            if (null != response) {
                List<TreeSubjectVo> childrenVos = Lists.newArrayList();
                List<Object> res = (List<Object>) response.getDataList();
                res.forEach(r -> {
                    TreeSubjectVo subjectVo = new TreeSubjectVo();
                    LinkedHashMap<String, Object> map1 = (LinkedHashMap<String, Object>) r;
                    subjectVo.setType("listNode");
                    subjectVo.setParentId((Integer) map.get("id"));
                    subjectVo.setId((Integer) map1.get("id"));
                    subjectVo.setDelete(map1.get("isDelete") == null ? false : (Boolean) map1.get("isDelete"));
                    subjectVo.setCreateTime((Long) map1.get("createTime"));
                    subjectVo.setCreator(map1.get("creator") == null ? 0 : (Integer) map1.get("creator"));
                    subjectVo.setSubjectName((String) map1.get("subjectName"));
                    subjectVo.setTreeName((String) map1.get("subjectName"));
                    subjectVo.setSubjectDetail((String) map1.get("subjectDetail"));
                    subjectVo.setSubjectType((String) map1.get("subjectType"));
                    subjectVo.setSubjectTypeName((String) map1.get("subjectTypeName"));
                    subjectVo.setPublishState((Integer) map1.get("publishState"));
                    subjectVo.setBelongTreeId((Integer) map1.get("belongTreeId"));
                    subjectVo.setScenes(map1.get("scenes") == null ? "" : (String) map1.get("scenes"));

                    //关联文字预案
                    List<TextPlan> textPlans = iTextPlanDao.findByAppId(String.valueOf(subjectVo.getId()));
                    textPlans.forEach(t -> {
                        TreeSubjectVo textTreeSubjectVo = new TreeSubjectVo();
                        textTreeSubjectVo.setParentId(Integer.valueOf(t.getAppId()));
                        textTreeSubjectVo.setTreeName(t.getTextName());
                        textTreeSubjectVo.setId((int) t.getId());
                        textTreeSubjectVo.setType("textNode");
                        subjectVo.getChildren().add(textTreeSubjectVo);
                    });

                    childrenVos.add(subjectVo);
                });
                treeItem.getChildren().addAll(childrenVos);
            }
            treeSubjectVos.add(treeItem);
        }
        return treeSubjectVos;
    }

}
