package com.yeejoin.amos.fas.business.service.intfc;

import com.yeejoin.amos.fas.business.param.AlarmParam;
import com.yeejoin.amos.fas.business.param.CommonPageInfoParam;
import com.yeejoin.amos.fas.business.param.RiskSourceParam;
import com.yeejoin.amos.fas.business.service.model.ContingencyDeviceStatus;
import com.yeejoin.amos.fas.business.service.model.FireEquimentDataRo;
import com.yeejoin.amos.fas.business.service.model.ProtalDataRo;
import com.yeejoin.amos.fas.business.vo.EquipCommunicationData;
import com.yeejoin.amos.fas.core.common.request.CommonPageable;
import com.yeejoin.amos.fas.core.common.response.RiskSourceTreeResponse;
import com.yeejoin.amos.fas.dao.entity.RiskSource;
import com.yeejoin.amos.fas.dao.entity.RiskSourceEquipment;
import com.yeejoin.amos.fas.dao.entity.RiskSourcePointInputitem;
import org.springframework.data.domain.Page;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public interface IRiskSourceService {

	/**
	 * 新增及维护风险点
	 * 
	 * @param map
	 * @return
	 */
	RiskSource editRiskSource(HashMap<String, Object> map) throws Exception;

	/**
	 * 删除风险点
	 * 
	 * @param riskSourceId
	 */
	void deleteRiskSource(Long[] riskSourceId) throws Exception;

	/**
	 * 根据参数分页查询风险点信息
	 * 
	 * @param param
	 * @return
	 */
	Page<HashMap<String, Object>> queryRiskSourceByPage(CommonPageInfoParam param);



	List<Map> queryForRegion( );

	List<Map> queryRPNReport();

	/**
	 * 上升率
	 * @return
	 */
	Map queryForRiseUp()throws Exception;


	List<Map> queryForMatrix();
	
	/**
	 * 获取所有风险点
	 * @return
	 */
	List<RiskSourceTreeResponse> findRiskSourceTrees();




	List<RiskSourceEquipment> bindFireEquiment(Long riskSourceId, List<RiskSourceEquipment> riskSourceEquipments);


	String [] removeBoundRelation(String [] idArray);


	//解除绑定

	/**
	 * 查询所有已绑定的关系列表
	 * @param riskSourceId
	 * @return
	 */
	Page queryForView(CommonPageable commonPageable,String riskSourceId);

	/**
	 * 查询指定风险点和设备之间的关系，包含绑定和未绑定
	 * @param equipmentId
	 * @return
	 */
	Page queryEquimentRelation(CommonPageable commonPageable, String riskSourceId,String equipmentId,String fname);
	
	/**
	 * 获取
	 * @param param
	 * @return
	 */
	Page<HashMap<String, Object>> getRiskSourcePoints(RiskSourceParam param);
	

	/**
	 * 绑定巡检点检查项
	 * @param riskSourceId
	 * @param pointInputitems
	 * @return
	 */
	List<RiskSourcePointInputitem> bindPointInputitem(Long riskSourceId, List<RiskSourcePointInputitem> pointInputitems);


	/**
	 * 处理巡检数据和设备数据
	 * @param deviceData
	 */
	String  processFireEqumtData(FireEquimentDataRo deviceData) throws Exception;




	boolean processTaskData(ProtalDataRo taskData) throws Exception;


	/**
	 * 	删除风险点巡检点检查项
	 * 
	 */
	
	void removeByRSIdAndPId(List<HashMap<String,String>> list);


	 boolean processProtalData(ProtalDataRo protalData) throws Exception;

	RiskSourceTreeResponse queryRiskSourceDetailById(Long id);


	/**
	 * 三维图统计
	 * @return
	 */
	Map queryFor3DStatistics();


	Map earlyWarning(Long riskSourceId);
	
	BigDecimal updateRiskSourceRpni(Long riskSourceId) throws Exception;

	List<HashMap<String,Object>> queryRiskAreaRpn();

	String processFireEqumtData(AlarmParam deviceData)  throws Exception;

	void saveData(List<AlarmParam> deviceDatas,String type);

	List<HashMap<String,Object>> queryRiskSourceSecondLevel();

	List<RiskSourceTreeResponse> findRiskSourceEquipStatistics();

	List<RiskSourceTreeResponse> findRiskSourceEquipStatistics(String[] type);

	List<RiskSourceTreeResponse> getCheckPointRiskSources();

	void queryContingencyDeviceStatus(ContingencyDeviceStatus contingencyDeviceStatus);

	List<Map> queryContingencyWater();

	List<Map> queryFmeaByPointId(Long pointId);
}
