package com.yeejoin.amos.fas.client.invoke;

import java.math.BigDecimal;
import java.util.concurrent.BlockingQueue;
import java.util.concurrent.Executors;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.ScheduledExecutorService;

import org.apache.log4j.Logger;

import com.yeejoin.amos.fas.business.service.intfc.IRiskSourceService;
import com.yeejoin.amos.fas.context.IotContext;

/**
 * 
 * 风险点消费队列
 */

public class RsDataQueue {
	
	private static final BlockingQueue<Long> blockingQueue = new LinkedBlockingQueue<Long>();
	ScheduledExecutorService service_apdu = null;
	IRiskSourceService riskSourceService = null;
	private volatile static RsDataQueue instance = null;
	
	private RsDataQueue() {
		riskSourceService = (IRiskSourceService) IotContext.getInstance().getBean(IRiskSourceService.class);
	}
	
	//获取RsDataQueue 的实例
    public static RsDataQueue getInstance(){
    	//先检查实例是否存在，如果不存在才进入下面的同步块
         if(instance == null){
        	 //同步块，线程安全的创建实例
             synchronized(RsDataQueue.class){
            	 //再次检查实例是否存在，如果不存在才真的创建实例
                 if(instance == null){
                     instance = new RsDataQueue();
                 }
             }
         }
         return instance;
    }
	
    /**
     * 启动apdu数据消费任务
     */
    public void start() {
    	service_apdu = Executors.newSingleThreadScheduledExecutor();
        // 第二个参数为首次执行的延时时间，第三个参数为定时执行的间隔时间
    	service_apdu.execute(task_runnable);
    }
    
	public void add(Long riskSourceId) {
		blockingQueue.add(riskSourceId);
	}
	
	Runnable task_runnable = new Runnable() {
        public void run() {
            while(true) {
            	try {
            		Long riskSourceId = blockingQueue.take();
            		BigDecimal rpni = new BigDecimal(0);
					if (riskSourceService != null) {
						rpni = riskSourceService.updateRiskSourceRpni(riskSourceId);			
					}
				} catch (Exception  e) {
					Logger.getLogger(this.getClass()).error(e.getMessage());
					e.printStackTrace();
				} 
            }
        }
    };
    
    
   
}
