
SET FOREIGN_KEY_CHECKS=0;

-- ----------------------------
-- Table structure for f_accident_type
-- ----------------------------
DROP TABLE IF EXISTS `f_accident_type`;
CREATE TABLE `f_accident_type` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `org_code` varchar(100) NOT NULL COMMENT '机构编号',
  `name` varchar(100) DEFAULT NULL COMMENT '事故类型',
  `influence` varchar(255) DEFAULT NULL COMMENT '失效/事故影响',
  `severity` varchar(255) DEFAULT NULL COMMENT '严重度',
  `dept_id` int(11) DEFAULT '0' COMMENT '维护部门',
  `create_by` int(11) DEFAULT '0' COMMENT '维护人员',
  `create_date` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '维护时间',
  `remark` varchar(255) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='事故类型表';

-- ----------------------------
-- Table structure for f_alarm
-- ----------------------------
DROP TABLE IF EXISTS `f_alarm`;
CREATE TABLE `f_alarm` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `org_code` varchar(100) NOT NULL COMMENT '机构编号',
  `code` varchar(255) DEFAULT NULL COMMENT '编号',
  `fire_equipment_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '消防设备id',
  `metric` text COMMENT '指标',
  `alarm_time` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '报警时间',
  `alarm_type` varchar(100) DEFAULT NULL COMMENT '报警类别:真实；误报',
  `create_date` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `remark` varchar(255) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='报警信息表';

-- ----------------------------
-- Table structure for f_equipment
-- ----------------------------
DROP TABLE IF EXISTS `f_equipment`;
CREATE TABLE `f_equipment` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `org_code` varchar(100) NOT NULL COMMENT '机构编号',
  `code` varchar(255) DEFAULT NULL COMMENT '编号',
  `name` varchar(255) DEFAULT NULL COMMENT '设备名称',
  `position3d` varchar(100) DEFAULT NULL COMMENT '3位坐标',
  `floor3d` varchar(100) DEFAULT NULL COMMENT '3维楼层',
  `is_indoor` bit(1) NOT NULL DEFAULT b'1' COMMENT '是否室内:0-否；1-是',
  `building` varchar(255) DEFAULT NULL COMMENT '建筑物',
  `room` varchar(255) DEFAULT NULL COMMENT '房间号',
  `address` varchar(255) DEFAULT NULL COMMENT '位置',
  `charge_dept_id` int(11) DEFAULT '0' COMMENT '责任部门',
  `charge_user_id` int(1) DEFAULT '0' COMMENT '责任人',
  `remark` varchar(255) DEFAULT NULL COMMENT '备注',
  `create_by` int(11) DEFAULT '0' COMMENT '创建者',
  `create_date` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='重点设备表';

-- ----------------------------
-- Table structure for f_equipment_fire_equipment
-- ----------------------------
DROP TABLE IF EXISTS `f_equipment_fire_equipment`;
CREATE TABLE `f_equipment_fire_equipment` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `equipment_id` bigint(20) NOT NULL COMMENT '设备id',
  `fire_equipment_id` bigint(20) NOT NULL COMMENT '消防装备id',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='重点设备与消防设备关联中间表';

-- ----------------------------
-- Table structure for f_evaluation_model
-- ----------------------------
DROP TABLE IF EXISTS `f_evaluation_model`;
CREATE TABLE `f_evaluation_model` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `org_code` varchar(100) NOT NULL COMMENT '机构编号',
  `name` varchar(100) DEFAULT NULL COMMENT '模型名称',
  `standard` text COMMENT '模型内容',
  `create_date` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '维护时间',
  `create_by` int(11) DEFAULT '0' COMMENT '创建者',
  `remark` varchar(255) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='评价模型表';


-- ----------------------------
-- Table structure for f_fire_car
-- ----------------------------
DROP TABLE IF EXISTS `f_fire_car`;
CREATE TABLE `f_fire_car` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `org_code` varchar(100) NOT NULL COMMENT '机构编号',
  `dept_id` int(100) DEFAULT '0' COMMENT '部门id',
  `type` varchar(255) DEFAULT NULL COMMENT '车辆类别',
  `name` varchar(255) DEFAULT NULL COMMENT '车辆名称',
  `position` varchar(100) DEFAULT NULL COMMENT '3维坐标',
  `floor_config` varchar(100) DEFAULT NULL COMMENT '楼层',
  `car_num` varchar(255) DEFAULT NULL COMMENT '车牌号',
  `engine_num` varchar(255) DEFAULT NULL COMMENT '发动机号',
  `model` varchar(255) DEFAULT NULL COMMENT '厂牌型号',
  `country` varchar(255) DEFAULT NULL COMMENT '国别',
  `state` varchar(255) DEFAULT NULL COMMENT '车辆状态',
  `performance_index` longtext COMMENT '性能指标',
  `remark` varchar(255) DEFAULT NULL COMMENT '备注',
  `create_by` int(11) DEFAULT '0' COMMENT '创建者id',
  `create_date` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='消防车表';

-- ----------------------------
-- Table structure for f_fire_equipment
-- ----------------------------
DROP TABLE IF EXISTS `f_fire_equipment`;
CREATE TABLE `f_fire_equipment` (
 `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `org_code` varchar(100) NOT NULL COMMENT '机构编号',
  `code` varchar(255) DEFAULT NULL COMMENT '编号',
  `equip_classify` int(11) DEFAULT '0' COMMENT '装备分类：0-设备类；1-耗材类;2-视频监控',
  `equip_type` varchar(255) DEFAULT NULL COMMENT '装备类型',
  `equip_code` varchar(255) DEFAULT NULL COMMENT '装备编码',
  `position3d` varchar(100) DEFAULT NULL COMMENT '3维坐标',
  `floor3d` varchar(100) DEFAULT NULL COMMENT '3维楼层',
  `is_indoor` bit(1) NOT NULL DEFAULT b'1' COMMENT '是否室内:0-否；1-是',
  `name` varchar(255) DEFAULT NULL COMMENT '装备名称',
  `model` varchar(255) DEFAULT NULL COMMENT '规格型号',
  `maintenance_cycle` int(11) DEFAULT '0' COMMENT '保养周期',
  `manufacturer` varchar(255) DEFAULT NULL COMMENT '厂商',
  `brand` varchar(255) DEFAULT NULL COMMENT '品牌',
  `production_date` date DEFAULT NULL COMMENT '生产日期',
  `effective_date` date DEFAULT NULL COMMENT '有效时间',
  `number` int(11) DEFAULT '0' COMMENT '数量',
  `unit` varchar(255) DEFAULT NULL COMMENT '单位',
  `production_area` varchar(255) DEFAULT NULL COMMENT '区域',
  `room` varchar(255) DEFAULT NULL COMMENT '房间',
  `remark` varchar(255) DEFAULT NULL COMMENT '备注',
  `create_by` int(11) DEFAULT '0' COMMENT '创建者',
  `create_date` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='消防装备表';

-- ----------------------------
-- Table structure for f_fire_equipment_point
-- ----------------------------
DROP TABLE IF EXISTS `f_fire_equipment_point`;
CREATE TABLE `f_fire_equipment_point` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `name` varchar(255) DEFAULT NULL COMMENT '名称',
  `code` varchar(255) DEFAULT NULL COMMENT '编号',
  `fire_equipment_id` bigint(20) NOT NULL COMMENT '消防装备id',
  `create_by` bigint(20) DEFAULT '0' COMMENT '创建者',
  `create_date` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '创建日期',
  `remark` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='消防装备点表';

-- ----------------------------
-- Table structure for f_fmea
-- ----------------------------
DROP TABLE IF EXISTS `f_fmea`;
CREATE TABLE `f_fmea` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `risk_source_id` bigint(20) NOT NULL COMMENT '风险点id',
  `risk_factors_id` bigint(20) DEFAULT '0' COMMENT '危险因素id',
  `evaluation_sid` bigint(20) DEFAULT '0' COMMENT '危险程度',
  `evaluation_oid` bigint(20) DEFAULT '0' COMMENT '故障频数',
  `evaluation_did` bigint(20) DEFAULT '0' COMMENT '探测度',
  `rpni` decimal(10,2) DEFAULT '0.00' COMMENT '固有rpn',
  `engineering` text COMMENT '工程措施',
  `management` text COMMENT '管理措施',
  `train` text COMMENT '培训教育',
  `protection` text COMMENT '个体防护',
  `disposal` text COMMENT '应急处置',
  `remark` varchar(255) DEFAULT NULL COMMENT '备注',
  `create_date` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  `create_by` int(11) DEFAULT '0' COMMENT '创建者',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='FEMA表';

-- ----------------------------
-- Table structure for f_preplan_picture
-- ----------------------------
DROP TABLE IF EXISTS `f_preplan_picture`;
CREATE TABLE `f_preplan_picture` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `equipment_id` bigint(20) NOT NULL COMMENT '设备编号',
  `type` int(11) NOT NULL COMMENT '类型',
  `name` varchar(255) DEFAULT NULL COMMENT '装备名称',
  `picture` text COMMENT '图片路径地址',
  `remark` varchar(255) DEFAULT NULL COMMENT '备注',
  `create_by` int(11) DEFAULT '0' COMMENT '创建者',
  `create_date` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='重点设备预案图';

-- ----------------------------
-- Table structure for f_risk_factor
-- ----------------------------
DROP TABLE IF EXISTS `f_risk_factor`;
CREATE TABLE `f_risk_factor` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `org_code` varchar(100) NOT NULL COMMENT '机构编号',
  `name` varchar(255) DEFAULT NULL COMMENT '名称',
  `accident_type_id` bigint(20) NOT NULL COMMENT '失效/事故影响',
  `type` varchar(255) DEFAULT NULL COMMENT '分类',
  `dept_id` int(11) DEFAULT '0' COMMENT '维护部门',
  `create_by` int(11) DEFAULT '0' COMMENT '维护人员',
  `create_date` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '维护时间',
  `remark` varchar(255) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='危险因素表';

-- ----------------------------
-- Table structure for f_risk_level
-- ----------------------------
DROP TABLE IF EXISTS `f_risk_level`;
CREATE TABLE `f_risk_level` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `org_code` varchar(100) NOT NULL COMMENT '机构编号',
  `level` varchar(100) DEFAULT NULL COMMENT '等级',
  `evaluation_model_id` bigint(20) DEFAULT '1' COMMENT '评价模型id',
  `severity` varchar(255) DEFAULT NULL COMMENT '严重度',
  `name` varchar(255) DEFAULT NULL COMMENT '结果描述',
  `color` varchar(255) DEFAULT NULL COMMENT '图标颜色',
  `create_by` int(11) DEFAULT '0' COMMENT '维护人员',
  `create_date` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '维护时间',
  `remark` varchar(255) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COMMENT='风险等级表';

-- ----------------------------
-- Table structure for f_risk_source
-- ----------------------------
DROP TABLE IF EXISTS `f_risk_source`;
CREATE TABLE `f_risk_source` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `org_code` varchar(100) NOT NULL COMMENT '机构编号',
  `code` varchar(255) DEFAULT NULL COMMENT '编号',
  `name` varchar(255) DEFAULT NULL COMMENT '装备名称',
  `position3d` varchar(100) DEFAULT NULL COMMENT '3维坐标',
  `floor3d` varchar(100) DEFAULT NULL COMMENT '3维楼层',
  `is_indoor` bit(1) NOT NULL DEFAULT b'1' COMMENT '是否室内:0-否；1-是',
  `parent_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '上级编号id',
  `risk_level_id` bigint(20) DEFAULT '0' COMMENT '风险等级id',
  `rpn` decimal(10,2) DEFAULT NULL COMMENT '实时rpn',
  `remark` varchar(255) DEFAULT NULL COMMENT '备注',
  `create_by` int(11) DEFAULT '0' COMMENT '创建者',
  `create_date` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='风险点表';

-- ----------------------------
-- Table structure for f_risk_source_equipment
-- ----------------------------
DROP TABLE IF EXISTS `f_risk_source_equipment`;
CREATE TABLE `f_risk_source_equipment` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `risk_source_id` bigint(20) NOT NULL COMMENT '风险点id',
  `equipment_id` bigint(20) DEFAULT '0' COMMENT '设备id',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='风险点关联重点设备表';

-- ----------------------------
-- Table structure for f_risk_source_point_inputitem
-- ----------------------------
DROP TABLE IF EXISTS `f_risk_source_point_inputitem`;
CREATE TABLE `f_risk_source_point_inputitem` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `risk_source_id` bigint(20) NOT NULL COMMENT '风险点id',
  `point_id` bigint(20) DEFAULT '0' COMMENT '巡检点id',
  `point_inputitem_id` bigint(20) DEFAULT '0' COMMENT '巡检点检查项id',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='风险点关联检查项表';

-- ----------------------------
-- Table structure for f_rpn_change_log
-- ----------------------------
DROP TABLE IF EXISTS `f_rpn_change_log`;
CREATE TABLE `f_rpn_change_log` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `risk_source_id` bigint(20) NOT NULL COMMENT '风险点id',
  `rpn` decimal(10,2) DEFAULT NULL COMMENT '实时rpn',
  `rpni` decimal(10,2) DEFAULT NULL COMMENT '固有rpn',
  `type` int(11) DEFAULT '0' COMMENT '变化类型：0-上升；1-下降',
  `trigger_by` bigint(20) DEFAULT '0' COMMENT '触发风险id',
  `remark` varchar(255) DEFAULT NULL COMMENT '备注',
  `create_date` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '创建时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='rpn变化流水表';
SET FOREIGN_KEY_CHECKS=1;
